@@ -8,10 +8,9 @@
 #' 
 #' @name SpecHelpers-package
 #' @aliases SpecHelpers-package SpecHelpers
-#' @docType package
 #' @author Bryan A. Hanson, DePauw University, Greencastle Indiana USA
 #' @rdname SpecHelpers-package
 #' @title Spectroscopy Related Utilities
 #' Maintainer: Bryan A. Hanson \email{hanson@@depauw.edu}
 #' @keywords package
-NULL
+"_PACKAGE"
